@@ -60,10 +60,14 @@ if [[ $INSTALL_OPTIONAL != false ]]; then
 	[[ $(command -v protoc) == "" ]] && echo "Installing protobuf" && extension --install protobuf && echo "Finished protobuf"
 fi
 
-if [ $BUILD_ALL == "false" ] && [[ $(command -v designer) == "" ]]; then
+RUN_INSTALL=false
+[[ ! $(pkg-config Qt6Mqtt --exists && echo $?) ]] && RUN_INSTALL=true
+[[ $(pkg-config Qt6Mqtt --exists && echo $?) == 0 ]] && [[ $(pkg-config Qt6Mqtt --modversion) != "6.9.2" ]] && RUN_INSTALL=true
+
+if [[ $BUILD_ALL == "false" ]] && [[ $RUN_INSTALL == "true" ]]; then
 	echo "qt" 											>> $EXTENSION/build_order.txt
 fi
-if [ $BUILD_ALL == "true" ]; then
+if [[ $BUILD_ALL == "true" ]]; then
 	echo "qt" 											>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 										>> $EXTENSION/build_order.txt
